@@ -3,13 +3,13 @@
 /**
  * url_parser.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This code provides various string manipulation functions that are
  * used by the rest of the Squirrelmail code.
  *
- * $Id: url_parser.php,v 1.40.2.1 2002/08/28 14:44:38 jmunro Exp $
+ * $Id: url_parser.php,v 1.44 2002/12/31 12:49:32 kink Exp $
  */
 
 function replaceBlock (&$in, $replace, $start, $end) {
@@ -49,7 +49,7 @@ function parseEmail (&$body) {
     foreach ($addresses as $email) {
         $comp_uri = '../src/compose.php?send_to='.urlencode($email);
         if ($compose_new_win == '1') {
-            $comp_uri  = 'javascript:void(0)" onClick="comp_in_new(false,'
+            $comp_uri  = 'javascript:void(0)" onClick="comp_in_new('
                        . "'$comp_uri'" . ')';
         }
         $comp_uri = '<a href="'.$comp_uri.'">'.$email.'</a>';
