@@ -3,7 +3,7 @@
 /**
  * Message and Spam Filter Plugin
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This plugin filters your inbox into different folders based upon given
@@ -22,32 +22,34 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * $Id: options.php,v 1.15.2.2 2002/08/20 15:00:02 jmunro Exp $
+ * $Id: options.php,v 1.26 2003/03/11 16:57:20 kink Exp $
  */
 
-   chdir ('..');
-   require_once('../src/validate.php');
-   require_once('../functions/page_header.php');
-   require_once('../functions/imap.php');
-   require_once('../src/load_prefs.php');
+/* Path for SquirrelMail required files. */
+define('SM_PATH','../../');
 
-   global $AllowSpamFilters;
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/imap.php');
+require_once(SM_PATH . 'functions/imap_mailbox.php');
+require_once(SM_PATH . 'include/load_prefs.php');
+require_once(SM_PATH . 'plugins/filters/filters.php');
 
-   displayPageHeader($color, 'None');
+global $AllowSpamFilters;
 
-   $username = $_SESSION['username'];
-   $key = $_COOKIE['key'];
-   $onetimepad = $_SESSION['onetimepad'];
-   $delimiter = $_SESSION['delimiter'];
-   if(isset($_GET['theid'])) {
-       $theid = $_GET['theid'];
-   }
-   if(isset($_POST['theid'])) {
-       $theid = $_POST['theid'];
-   }
-   if(isset($_GET['action'])) {
-       $action = $_GET['action'];
-   }
+displayPageHeader($color, 'None');
+
+/* get globals */
+sqgetGlobalVar('username', $username, SQ_SESSION);
+sqgetGlobalVar('key', $key, SQ_COOKIE);
+sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
+sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
+
+sqgetGlobalVar('theid', $theid);
+sqgetGlobalVar('action', $action, SQ_GET);
+
+// FIXME: use sqgetGlobalVar below.
 
    if (isset($_POST['filter_submit'])) {
       if(isset($_GET['theid'])) {
@@ -61,19 +63,19 @@
       $filter_where  = $_POST['filter_where'];
       $filter_folder = $_POST['filter_folder'];
 
-      $filter_what = ereg_replace(",", " ", $filter_what);
+      $filter_what = str_replace(',', ' ', $filter_what);
       $filter_what = str_replace("\\\\", "\\", $filter_what);
-      $filter_what = str_replace("\\\"", "\"", $filter_what);
-      $filter_what = str_replace("\"", "&quot;", $filter_what);
+      $filter_what = str_replace("\\\"", '"', $filter_what);
+      $filter_what = str_replace('"', '&quot;', $filter_what);
 
       if (($filter_where == 'Header') && (strchr($filter_what,':') == '')) {
          print ('WARNING! Header filters should be of the format "Header: value"<BR>');
 	 $action = 'edit';
       }
-      setPref($data_dir, $username, "filter".$theid, $filter_where.",".$filter_what.",".$filter_folder);
-      $filters[$theid]["where"] = $filter_where;
-      $filters[$theid]["what"] = $filter_what;
-      $filters[$theid]["folder"] = $filter_folder;
+      setPref($data_dir, $username, 'filter'.$theid, $filter_where.','.$filter_what.','.$filter_folder);
+      $filters[$theid]['where'] = $filter_where;
+      $filters[$theid]['what'] = $filter_what;
+      $filters[$theid]['folder'] = $filter_folder;
    } elseif (isset($action) && $action == 'delete') {
       remove_filter($theid);
    } elseif (isset($action) && $action == 'move_up') {
@@ -82,47 +84,49 @@
       filter_swap($theid, $theid + 1);
    } elseif (isset($_POST['user_submit'])) {
        setPref($data_dir, $username, 'filters_user_scan', $_POST['filters_user_scan_set']);
-       echo "<br><center><b>"._("Saved Scan type")."</b></center>\n";
+       echo '<br><center><b>'._("Saved Scan type")."</b></center>\n";
    }
 
    $filters = load_filters();
    $filters_user_scan = getPref($data_dir, $username, 'filters_user_scan');
 
-   echo '<br>' .
-        '<table width=95% align=center border=0 cellpadding=2 cellspacing=0>'.
-        "<tr><td bgcolor=\"$color[0]\">".
-        '<center><b>' . _("Options") . ' -  ' . _("Message Filtering") . '</b></center>'.
-        '</td></tr></table>'.
+   echo html_tag( 'table',
+            html_tag( 'tr',
+                html_tag( 'td',
+                    '<center><b>' . _("Options") . ' -  ' . _("Message Filtering") . '</b></center>' ,
+                'left', $color[0] )
+            ) ,
+         'center', '', 'width="95%" border="0" cellpadding="2" cellspacing="0"' ) .
 
         '<br><form method=post action="options.php">'.
         '<center>'.
-        '<table cellpadding=2 cellspacing=0 border=0>'.
-        '<tr>'.
-            '<th align=right nowrap>' . _("What to Scan:") . '</th>'.
-            '<td><select name="filters_user_scan_set">'.
+        html_tag( 'table', '', '', '', 'border="0" cellpadding="2" cellspacing="0"' ) .
+            html_tag( 'tr' ) .
+                html_tag( 'th', _("What to Scan:"), 'right', '', 'nowrap' ) .
+                html_tag( 'td', '', 'left' ) .
+            '<select name="filters_user_scan_set">'.
             '<option value=""';
     if ($filters_user_scan == '') {
-        echo ' SELECTED';
+        echo ' selected';
     }
     echo '>' . _("All messages") . '</option>'.
             '<option value="new"';
     if ($filters_user_scan == 'new') {
-        echo ' SELECTED';
+        echo ' selected';
     }
     echo '>' . _("Only unread messages") . '</option>' .
             '</select>'.
         '</td>'.
-        '<td><input type=submit name="user_submit" value="' . _("Save") . '"></td></tr>'.
+        html_tag( 'td', '<input type=submit name="user_submit" value="' . _("Save") . '">', 'left' ) .
         '</table>'.
         '</center>'.
         '</form>'.
 
-        '<center>[<a href="options.php?action=add">' . _("New") .
-        '</a>] - [<a href="../../src/options.php">' . _("Done") . '</a>]</center><br>';
+        html_tag( 'div', '[<a href="options.php?action=add">' . _("New") .
+            '</a>] - [<a href="'.SM_PATH.'src/options.php">' . _("Done") . '</a>]' ,
+        'center' ) . '<br>';
 
     if (isset($action) && ($action == 'add' || $action == 'edit')) {
-        $username = $_SESSION['username'];
-        $key = $_COOKIE['key'];
 
         $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
         $boxes = sqimap_mailbox_list($imapConnection);
@@ -130,12 +134,12 @@
         if ( !isset($theid) ) {
             $theid = count($filters);
         }
-        echo '<center>'.
+        echo html_tag( 'div', '', 'center' ) .
              '<form action="options.php" method=post>'.
-             '<table cellpadding=2 cellspacing=0 border=0>'.
-             '<tr>'.
-                '<td>' . _("Match:") . '</td>'.
-                '<td>'.
+             html_tag( 'table', '', '', '', 'border="0" cellpadding="2" cellspacing="0"' ) .
+             html_tag( 'tr' ) .
+                html_tag( 'td', _("Match:"), 'left' ) .
+                html_tag( 'td', '', 'left' ) .
                     '<select name=filter_where>';
 
         $L = isset($filters[$theid]['where']);
@@ -161,11 +165,9 @@
         echo         '</select>'.
                 '</td>'.
             '</tr>'.
-            '<tr>'.
-                '<td align=right>'.
-                    _("Contains:").
-                '</td>'.
-                '<td>'.
+            html_tag( 'tr' ) .
+                html_tag( 'td', _("Contains:"), 'right' ) .
+                html_tag( 'td', '', 'left' ) .
                     '<input type=text size=32 name=filter_what value="';
         if (isset($filters[$theid]['what'])) {
             echo $filters[$theid]["what"];
@@ -173,25 +175,15 @@
         echo '">'.
                 '</td>'.
             '</tr>'.
-            '<tr>'.
-                '<td>'.
-                    _("Move to:").
-                '</td>'.
-                '<td>'.
+            html_tag( 'tr' ) .
+                html_tag( 'td', _("Move to:"), 'left' ) .
+                html_tag( 'td', '', 'left' ) .
                     '<tt>'.
                     '<select name=filter_folder>';
-
-        for ($i = 0; $i < count($boxes); $i++) {
-            if (! in_array('noselect', $boxes[$i]['flags'])) {
-                $box = $boxes[$i]['unformatted'];
-                $box2 = str_replace(' ', '&nbsp;', $boxes[$i]['formatted']);
-                if (isset($filters[$theid]['folder']) &&
-                    $filters[$theid]['folder'] == $box)
-                echo "<OPTION VALUE=\"$box\" SELECTED>$box2</option>";
-                else
-                echo "<OPTION VALUE=\"$box\">$box2</option>";
-            }
-        }
+        $selected = 0;
+        if ( isset($filters[$theid]['folder']) )
+          $selected = array(strtolower($filters[$theid]['folder']));
+        echo sqimap_mailbox_option_list(0, $selected, 0, $boxes);
         echo         '</tt>'.
                     '</select>'.
                 '</td>'.
@@ -200,21 +192,28 @@
             '<input type=submit name=filter_submit value=' . _("Submit") . '>'.
             "<input type=hidden name=theid value=$theid>".
             '</form>'.
-            '</center>';
+            '</div>';
 
     }
 
-	echo '<table border=0 cellpadding=3 cellspacing=0 align=center>';
+	echo html_tag( 'table', '', 'center', '', 'border="0" cellpadding="3" cellspacing="0"' );
 
-    for ($i=0; $i < count($filters); $i++) {
+    for ($i=0, $num = count($filters); $i < $num; $i++) {
 
         $clr = (($i % 2)?$color[0]:$color[9]);
         $fdr = ($folder_prefix)?str_replace($folder_prefix, "", $filters[$i]["folder"]):$filters[$i]["folder"];
-        echo "<tr bgcolor=\"$clr\"><td><small>".
-            "[<a href=\"options.php?theid=$i&action=edit\">" . _("Edit") . '</a>]'.
-            '</small></td><td><small>'.
-            "[<a href=\"options.php?theid=$i&action=delete\">" . _("Delete") . '</a>]'.
-            '</small></td><td align=center><small>[';
+        echo html_tag( 'tr', '', '', $clr ) .
+                   html_tag( 'td',
+                       '<small>' .
+                       "[<a href=\"options.php?theid=$i&action=edit\">" . _("Edit") . '</a>]'.
+                       '</small>' ,
+                   'left' ) .
+                   html_tag( 'td',
+                       '<small>' .
+                       "[<a href=\"options.php?theid=$i&action=delete\">" . _("Delete") . '</a>]'.
+                       '</small>' ,
+                   'left' ) .
+                   html_tag( 'td', '', 'center' ) . '<small>[';
 
         if (isset($filters[$i + 1])) {
             echo "<a href=\"options.php?theid=$i&action=move_down\">" . _("Down") . '</a>';
@@ -225,14 +224,17 @@
         if ($i > 0) {
             echo "<a href=\"options.php?theid=$i&action=move_up\">" . _("Up") . '</a>';
         }
-        echo ']</small></td><td>-</td><td>';
+        echo ']</small></td>'.
+            html_tag( 'td', '-', 'left' ) .
+            html_tag( 'td', '', 'left' );
         printf( _("If <b>%s</b> contains <b>%s</b> then move to <b>%s</b>"), _($filters[$i]['where']), $filters[$i]['what'], $fdr );
         echo '</td></tr>';
 
     }
     echo '</table>'.
-        '<table width=80% align=center border=0 cellpadding=2 cellspacing=0">'.
-            '<tr><td>&nbsp</td></tr>'.
-        '</table>';
-
+        html_tag( 'table',
+            html_tag( 'tr',
+                html_tag( 'td', '&nbsp;', 'left' )
+            ) ,
+        'center', '', 'width="80%" border="0" cellpadding="2" cellspacing="0"' );
 ?>
