@@ -1,14 +1,16 @@
 <?php
 
 /* setup file for the IMAP server info plugin
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *   
  * by: Jason Munro jason@stdbev.com
- *
+ * 
+ * $Id: setup.php,v 1.4 2002/12/31 12:49:36 kink Exp $
+ * 
  */
 
-require_once ('../plugins/info/functions.php');
+require_once (SM_PATH . 'plugins/info/functions.php');
 
 function squirrelmail_plugin_init_info() {
     global $squirrelmail_plugin_hooks;
