@@ -1,25 +1,28 @@
 <?php
-   /**
-    * options.php
-    *
-    * Copyright (c) 1999-2002 The SquirrelMail Project Team
-    * Licensed under the GNU GPL. For full terms see the file COPYING.
-    *
-    * Pick your translator to translate the body of incoming mail messages
-    *
-    * $Id: options.php,v 1.7.2.2 2002/08/21 18:06:41 jmunro Exp $
-    */
 
-   chdir('..');
-   require_once('../src/validate.php');
-   require_once('../functions/strings.php');
-   require_once('../functions/page_header.php');
-   require_once('../functions/display_messages.php');
-   require_once('../functions/imap.php');
-   require_once('../functions/array.php');
-   require_once('../functions/i18n.php');
-   require_once('../src/load_prefs.php');
-   displayPageHeader($color, 'None');
+/**
+ * options.php
+ *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * Pick your translator to translate the body of incoming mail messages
+ *
+ * $Id: options.php,v 1.17 2003/02/02 10:07:05 tokul Exp $
+ */
+
+/* Path for SquirrelMail required files. */
+define('SM_PATH','../../');
+
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/display_messages.php');
+require_once(SM_PATH . 'functions/imap.php');
+require_once(SM_PATH . 'include/load_prefs.php');
+
+    displayPageHeader($color, 'None');
 
     if (isset($_POST['submit_translate']) && $_POST['submit_translate'] ) {
         if (isset($_POST['translate_translate_server'])) {
@@ -89,8 +92,7 @@
     }
 
 ?>
-   <br>
-   <table width="100%" align=center border=0 cellpadding=2 cellspacing=0><tr><td bgcolor="<?php echo $color[0] ?>">
+   <table width="95%" align=center border=0 cellpadding=1 cellspacing=0><tr><td bgcolor="<?php echo $color[0] ?>">
       <center><b><?php echo _("Options") . ' - '. _("Translator"); ?></b></center>
    </td></tr></table>
 
@@ -105,9 +107,9 @@
     ShowTrad( 'Babelfish',
               _("13 language pairs, maximum of 1000 characters translated, powered by Systran"),
               'http://babelfish.altavista.com/' );
-    ShowTrad( 'Translator.Go.com',
-              _("10 language pairs, maximum of 25 kilobytes translated, powered by Systran"),
-              'http://translator.go.com/' );
+//    ShowTrad( 'Translator.Go.com',
+//              _("10 language pairs, maximum of 25 kilobytes translated, powered by Systran"),
+//              'http://translator.go.com/' );
     ShowTrad( 'Dictionary.com',
               _("12 language pairs, no known limits, powered by Systran"),
               'http://www.dictionary.com/translate' );
@@ -130,7 +132,7 @@
             '<td><select name="translate_translate_server">';
 
     ShowOption('server', 'babelfish', 'Babelfish');
-    ShowOption('server', 'go', 'Go.com');
+//    ShowOption('server', 'go', 'Go.com');
     ShowOption('server', 'dictionary', 'Dictionary.com');
     ShowOption('server', 'intertran', 'Intertran');
     ShowOption('server', 'gpltrans', 'GPLTrans');
