@@ -3,41 +3,36 @@
 /**
  * addrbook_search_html.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Handle addressbook searching with pure html.
  *
  * This file is included from compose.php
  *
- * NOTE: A lot of this code is similar to the code in
- *       addrbook_search.html -- If you change one, change
- *       the other one too!
- *
- * $Id: addrbook_search_html.php,v 1.47.2.3 2002/09/14 15:37:51 jmunro Exp $
+ * $Id: addrbook_search_html.php,v 1.58 2003/03/27 16:47:45 philippe_mingo Exp $
  */
 
-require_once('../src/validate.php');
-require_once('../functions/date.php');
-require_once('../functions/smtp.php');
-require_once('../functions/display_messages.php');
-require_once('../functions/addressbook.php');
-require_once('../functions/plugin.php');
-require_once('../functions/strings.php');
-
-
-$session = $_POST['session'];
-$mailbox = $_POST['mailbox'];
-if ( isset($_POST['addrquery']) ) {
-    $addrquery = $_POST['addrquery'];
-}
-if ( isset($_POST['listall']) ) {
-    $listall = $_POST['listall'];
-}
-if ( isset($_POST['backend'] ) ) {
-    $backend = $_POST['backend'];
+/* Path for SquirrelMail required files. */
+if (! defined('SM_PATH') ) {
+	define('SM_PATH','../');
 }
 
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/global.php');
+require_once(SM_PATH . 'functions/date.php');
+require_once(SM_PATH . 'functions/display_messages.php');
+require_once(SM_PATH . 'functions/addressbook.php');
+require_once(SM_PATH . 'functions/plugin.php');
+require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'functions/html.php');
+
+sqgetGlobalVar('session',   $session,   SQ_POST);
+sqgetGlobalVar('mailbox',   $mailbox,   SQ_POST);
+sqgetGlobalVar('addrquery', $addrquery, SQ_POST);
+sqgetGlobalVar('listall',   $listall,   SQ_POST);
+sqgetGlobalVar('backend',   $backend,   SQ_POST);
 
 /* Insert hidden data */
 function addr_insert_hidden() {
@@ -68,7 +63,7 @@ function addr_insert_hidden() {
 
 /* List search results */
 function addr_display_result($res, $includesource = true) {
-    global $color, $javascript_on, $PHP_SELF;
+    global $color, $javascript_on, $PHP_SELF, $squirrelmail_language;
 
     if (sizeof($res) <= 0) return;
 
@@ -97,46 +92,65 @@ if ($javascript_on) {
             '&nbsp;&nbsp;'.
             '<a href="#" onClick="CheckAll(\'B\');">' . _("All") . '</a>';
     }
-    else {
-        $chk_all = '';
-    }
-    echo '<TABLE BORDER="0" WIDTH="98%" ALIGN="center">' .
-           '<TR BGCOLOR="' . $color[9] . '"><TH ALIGN="left">&nbsp;' . $chk_all . '</TH>' .
-          '<TH ALIGN="left">&nbsp;' . _("Name") . '</TH>' .
-          '<TH ALIGN="left">&nbsp;' . _("E-mail") . '</TH>' .
-          '<TH ALIGN="left">&nbsp;' . _("Info") . '</TH>';
-
-
+    echo html_tag( 'table', '', 'center', '', 'border="0" width="98%"' ) .
+    html_tag( 'tr', '', '', $color[9] ) .
+    html_tag( 'th', '&nbsp;' . $chk_all, 'left' ) .
+    html_tag( 'th', '&nbsp;' . _("Name"), 'left' ) .
+    html_tag( 'th', '&nbsp;' . _("E-mail"), 'left' ) .
+    html_tag( 'th', '&nbsp;' . _("Info"), 'left' );
 
     if ($includesource) {
-        echo '<TH ALIGN=left WIDTH="10%">&nbsp;' . _("Source"). '</TH>';
+        echo html_tag( 'th', '&nbsp;' . _("Source"), 'left', '', 'width="10%"' );
     }
 
-    echo "</TR>\n";
+    echo "</tr>\n";
 
     foreach ($res as $row) {
-        echo '<tr';
-        if ($line % 2) { echo ' bgcolor="' . $color[0] . '"'; }
-        echo ' nowrap><td nowrap align=center width="5%">' .
+        $tr_bgcolor = '';
+        $email = AddressBook::full_address($row);
+        if ($line % 2) { $tr_bgcolor = $color[0]; }
+        if ($squirrelmail_language == 'ja_JP')
+            {
+        echo html_tag( 'tr', '', '', $tr_bgcolor, 'nowrap' ) .
+        html_tag( 'td',
              '<input type=checkbox name="send_to_search[T' . $line . ']" value = "' .
-             htmlspecialchars($row['email']) . '">&nbsp;' . _("To") . '&nbsp;' .
+             htmlspecialchars($email) . '">&nbsp;' . _("To") . '&nbsp;' .
              '<input type=checkbox name="send_to_search[C' . $line . ']" value = "' .
-             htmlspecialchars($row['email']) . '">&nbsp;' . _("Cc") . '&nbsp;' .
+             htmlspecialchars($email) . '">&nbsp;' . _("Cc") . '&nbsp;' .
              '<input type=checkbox name="send_to_search[B' . $line . ']" value = "' .
-             htmlspecialchars($row['email']) . '">&nbsp;' . _("Bcc") . '&nbsp;' . 
-             '</td><td nowrap>&nbsp;' . $row['name'] . '&nbsp;</td>' .
-             '<td >' . $row['email'] . '&nbsp;</td>' .
-             '<td nowrap>&nbsp;' . $row['label'] . '&nbsp;</td>';
+             htmlspecialchars($email) . '">&nbsp;' . _("Bcc") . '&nbsp;' ,
+        'center', '', 'width="5%" nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['lastname']) . ' ' . htmlspecialchars($row['firstname']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
+            } else {
+        echo html_tag( 'tr', '', '', $tr_bgcolor, 'nowrap' ) .
+        html_tag( 'td',
+             '<input type=checkbox name="send_to_search[T' . $line . ']" value = "' .
+             htmlspecialchars($email) . '">&nbsp;' . _("To") . '&nbsp;' .
+             '<input type=checkbox name="send_to_search[C' . $line . ']" value = "' .
+             htmlspecialchars($email) . '">&nbsp;' . _("Cc") . '&nbsp;' .
+             '<input type=checkbox name="send_to_search[B' . $line . ']" value = "' .
+             htmlspecialchars($email) . '">&nbsp;' . _("Bcc") . '&nbsp;' ,
+        'center', '', 'width="5%" nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['name']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
+            }
+
          if ($includesource) {
-             echo '<td nowrap>&nbsp;' . $row['source'] . '&nbsp;</td>';
+             echo html_tag( 'td', '&nbsp;' . $row['source'] . '&nbsp;', 'left', '', 'nowrap' );
          }
          echo "</tr>\n";
          $line ++;
     }
-    echo '<TR><TD ALIGN=center COLSPAN=';
-    if ($includesource) { echo '5'; } else { echo '4'; }
-    echo '><INPUT TYPE=submit NAME="addr_search_done" VALUE="' .
-         _("Use Addresses") . '"></TD></TR>' .
+    if ($includesource) { $td_colspan = '5'; } else { $td_colspan = '4'; }
+    echo html_tag( 'tr',
+                html_tag( 'td',
+                        '<INPUT TYPE=submit NAME="addr_search_done" VALUE="' .
+                        _("Use Addresses") . '">' ,
+                'center', '', 'colspan="'. $td_colspan .'"' )
+            ) .
          '</TABLE>' .
          '<INPUT TYPE=hidden VALUE=1 NAME="html_addr_search_done">' .
          '</FORM>';
@@ -153,21 +167,23 @@ else {
 /* Initialize addressbook */
 $abook = addressbook_init();
 
-?>
 
-<br>
-<table width="95%" align=center cellpadding=2 cellspacing=2 border=0>
-<tr><td bgcolor="<?php echo $color[0] ?>">
-   <center><b><?php echo _("Address Book Search") ?></b></center>
-</td></tr></table>
+echo '<br>' .
+html_tag( 'table',
+    html_tag( 'tr',
+        html_tag( 'td', '<b>' . _("Address Book Search") . '</b>', 'center', $color[0] )
+    ) ,
+'center', '', 'width="95%" cellpadding="2" cellspacing="2" border="0"' );
 
-<?php
 
 /* Search form */
-echo "<CENTER>\n<TABLE BORDER=0><TR><TD NOWRAP VALIGN=middle>\n" .
-     '<FORM METHOD=post NAME=f ACTION="' . $PHP_SELF .
-     '?html_addr_search=true">' . "\n<CENTER>\n" .
-     '  <nobr><STRONG>' . _("Search for") . "</STRONG>\n";
+echo '<center>' .
+    html_tag( 'table', '', 'center', '', 'border="0"' ) .
+    html_tag( 'tr' ) .
+    html_tag( 'td', '', 'left', '', 'nowrap valign="middle"' ) . "\n" .
+    '<FORM METHOD=post NAME=f ACTION="' . $PHP_SELF .
+    '?html_addr_search=true">' . "\n<CENTER>\n" .
+    '  <nobr><STRONG>' . _("Search for") . "</STRONG>\n";
 addr_insert_hidden();
 if (! isset($addrquery))
     $addrquery = '';
@@ -200,7 +216,7 @@ echo '<INPUT TYPE=submit VALUE="' . _("Search") . '">' .
      '" NAME=listall>' . "\n" .
      '</FORM></center></TD></TR></TABLE>' . "\n";
 addr_insert_hidden();
-echo '</CENTER>';
+echo '</center>';
 do_hook('addrbook_html_search_below');
 /* End search form */
 
@@ -225,10 +241,10 @@ if ($addrquery == '' && empty($listall)) {
             usort($res,'alistcmp');
             addr_display_result($res, false);
         } else {
-            echo '<P ALIGN=center><STRONG>' .
+            echo html_tag( 'p', '<strong><br>' .
                  sprintf(_("Unable to list addresses from %s"), 
-                     $abook->backends[$backend]->sname) .
-                 "</STRONG></P>\n";
+                 $abook->backends[$backend]->sname) . "</strong>\n" ,
+            'center' );
         }
 
     } else {
@@ -250,14 +266,17 @@ else {
         }
 
         if (!is_array($res)) {
-            echo '<P ALIGN=center><B><BR>' .
-                 _("Your search failed with the following error(s)") . ':<br>' .
-                  $abook->error . "</B></P>\n</BODY></HTML>\n";
+            echo html_tag( 'p', '<b><br>' .
+                             _("Your search failed with the following error(s)") .
+                            ':<br>' . $abook->error . "</b>\n" ,
+                   'center' ) .
+            "\n</BODY></HTML>\n";
         } else {
             if (sizeof($res) == 0) {
-                echo '<P ALIGN=center><BR><B>' .
-                     _("No persons matching your search was found") .
-                     ".</B></P>\n</BODY></HTML>\n";
+                echo html_tag( 'p', '<br><b>' .
+                                 _("No persons matching your search was found") . "</b>\n" ,
+                       'center' ) .
+                "\n</BODY></HTML>\n";
             } else {
                 addr_display_result($res);
             }
