@@ -3,23 +3,52 @@
 /**
  * search.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: search.php,v 1.67.2.8 2002/09/14 15:20:02 jmunro Exp $
+ * $Id: search.php,v 1.92 2003/03/27 16:47:47 philippe_mingo Exp $
  */
 
-require_once('../src/validate.php');
-require_once('../functions/imap.php');
-require_once('../functions/imap_search.php');
-require_once('../functions/imap_utf7_decode_local.php');
-require_once('../functions/array.php');
-require_once('../functions/strings.php');
+/* Path for SquirrelMail required files. */
+define('SM_PATH','../');
+
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/imap.php');
+require_once(SM_PATH . 'functions/imap_search.php');
+require_once(SM_PATH . 'functions/imap_mailbox.php');
+require_once(SM_PATH . 'functions/strings.php');
 
 global $allow_thread_sort;
 
-/*  here are some functions, could go in imap_search.php
+/* get globals we may need */
 
+sqgetGlobalVar('username', $username, SQ_SESSION);
+sqgetGlobalVar('key', $key, SQ_COOKIE);
+sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
+sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
+
+if (isset($_GET['mailbox'])) {
+    $mailbox = strip_tags($_GET['mailbox']);
+}
+if (isset($_GET['submit'])) {
+    $submit = strip_tags($_GET['submit']);
+}
+if (isset($_GET['what'])) {
+    $what = $_GET['what'];
+}
+if (isset($_GET['where'])) {
+    $where = strip_tags($_GET['where']);
+}
+if (isset($_GET['checkall'])) {
+    $checkall = strip_tags($_GET['checkall']);
+}
+if (isset($_GET['count'])) {
+    $count = strip_tags($_GET['count']);
+}
+/* end of get globals */
+
+/*  here are some functions, could go in imap_search.php
     this was here, pretty handy  */
 function s_opt( $val, $sel, $tit ) {
     echo "            <option value=\"$val\"";
@@ -102,7 +131,7 @@ function forget_recent($forget_index, $username, $data_dir) {
     $attributes = get_recent( $username, $data_dir);
     reset($types);
     foreach ($types as $key) {
-        array_splice($attributes[$key], $forget_index, 1);
+        array_splice($attributes[$key], $forget_index - 1, 1);
         array_unshift($attributes[$key], '');
     }
     reset($types);
@@ -159,6 +188,47 @@ function save_recent($save_index, $username, $data_dir) {
     }
 }
 
+function printSearchMessages($msgs,$mailbox, $cnt, $imapConnection, $where, $what, $usecache = false, $newsort = false) {
+    global $sort, $color;
+    
+	if ($cnt > 0) {
+	   $msort = calc_msort($msgs, $sort);
+       if ( $mailbox == 'INBOX' ) {
+           $showbox = _("INBOX");
+       } else {
+            $showbox = imap_utf7_decode_local($mailbox);
+       }
+       echo html_tag( 'div', '<b><big>' . _("Folder:") . ' '. $showbox.'</big></b>','center') . "\n";
+
+
+       $msg_cnt_str = get_msgcnt_str(1, $cnt, $cnt);
+       $toggle_all = get_selectall_link(1, $sort);
+
+       echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
+       echo '<tr><td>';
+
+       mail_message_listing_beginning($imapConnection, $mailbox, $sort, 
+                                       $msg_cnt_str, $toggle_all, 1);
+
+       echo '</td></tr>';
+       echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';  
+       echo '<tr><td>';
+       echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
+       echo '     <tr><td>';
+       echo '       <table width="100%" cellpadding="1" cellspacing="0" align="center" border="0" bgcolor="'.$color[5].'">';
+       echo '<tr><td>';
+
+       printHeader($mailbox, 6, $color, false);
+
+       displayMessageArray($imapConnection, $cnt, 1, 
+		          $msort, $mailbox, $sort, $color, $cnt, $where, $what);
+
+       echo '</td></tr></table></td></tr></table>';
+       mail_message_listing_end($cnt, '', $msg_cnt_str, $color); 
+       echo '</td></tr></table>';
+    }
+}			      
+
 /* ------------------------ main ------------------------ */
 
 /*  reset these arrays on each page load just in case  */
@@ -168,33 +238,6 @@ $search_all = 'none';
 $perbox_count = array ();
 $recent_count = getPref($data_dir, $username, 'search_memory', 0);
 
-/* get globals we may need */
-
-$key = $_COOKIE['key'];
-$username = $_SESSION['username'];
-$onetimepad = $_SESSION['onetimepad'];
-$delimiter = $_SESSION['delimiter'];
-
-if (isset($_GET['mailbox'])) {
-    $mailbox = strip_tags($_GET['mailbox']);
-}
-if (isset($_GET['submit'])) {
-    $submit = strip_tags($_GET['submit']);
-}
-if (isset($_GET['what'])) {
-    $what = $_GET['what'];
-}
-if (isset($_GET['where'])) {
-    $where = strip_tags($_GET['where']);
-}
-if (isset($_GET['checkall'])) {
-    $checkall = strip_tags($_GET['checkall']);
-}
-if (isset($_GET['count'])) {
-    $count = strip_tags($_GET['count']);
-}
-/* end of get globals */
-
 /*  get mailbox names  */
 $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $boxes = sqimap_mailbox_list($imapConnection);
@@ -227,7 +270,7 @@ if ( !isset( $submit ) ) {
     }
 }
 elseif ($submit == 'forget') {
-    forget_recent(($count-1), $username, $data_dir);
+    forget_recent($count, $username, $data_dir);
 }
 elseif ($submit == 'save') {
     save_recent($count, $username, $data_dir);
@@ -238,12 +281,11 @@ elseif ($submit == 'delete') {
 
 do_hook('search_before_form');
 
-echo "<BR>\n".
-     "<table width=\"100%\">\n".
-        "<TR><td bgcolor=\"$color[0]\">\n".
-            "<CENTER><B>" . _("Search") . "</B></CENTER>\n".
-        "</TD></TR>\n".
-     "</TABLE>\n";
+echo html_tag( 'table',
+         html_tag( 'tr', "\n" .
+             html_tag( 'td', '<b>' . _("Search") . '</b>', 'center', $color[0] )
+         ) ,
+     '', '', 'width="100%"') . "\n";
 
 /*  update the recent and saved searches from the pref files  */
 $attributes = get_recent($username, $data_dir);
@@ -253,47 +295,54 @@ $count_all = 0;
 
 /* Saved Search Table */
 if ($saved_count > 0) {
-    echo "<BR>\n"
-    . "<TABLE WIDTH=\"95%\" BGCOLOR=\"$color[9]\" ALIGN=\"CENTER\" CELLPADDING=1 CELLSPACING=1>"
-    . '<TR><TD align=center><B>Saved Searches</B></TD></TR><TR><TD>'
-    . '<TABLE WIDTH="100%" ALIGN="CENTER" CELLPADDING=0 CELLSPACING=0>';
+    echo "<br>\n"
+    . html_tag( 'table', '', 'center', $color[9], 'width="95%" cellpadding="1" cellspacing="1" border="0"' )
+    . html_tag( 'tr',
+          html_tag( 'td', '<b>Saved Searches</b>', 'center' )
+      )
+    . html_tag( 'tr' )
+    . html_tag( 'td' )
+    . html_tag( 'table', '', 'center', '', 'width="100%" cellpadding="2" cellspacing="2" border="0"' );
     for ($i=0; $i < $saved_count; ++$i) {
         if ($i % 2) {
-            echo "<TR BGCOLOR=\"$color[0]\">";
+            echo html_tag( 'tr', '', '', $color[0] );
         } else {
-            echo "<TR BGCOLOR=\"$color[4]\">";
+            echo html_tag( 'tr', '', '', $color[4] );
         }
-        echo "<TD WIDTH=\"35%\">".htmlentities($saved_attributes['saved_folder'][$i])."</TD>"
-        . "<TD ALIGN=LEFT>".htmlentities($saved_attributes['saved_what'][$i])."</TD>"
-        . "<TD ALIGN=CENTER>".htmlentities($saved_attributes['saved_where'][$i])."</TD>"
-        . '<TD ALIGN=RIGHT>'
-        .   '<A HREF=search.php'
-        .     '?mailbox=' . urlencode($saved_attributes['saved_folder'][$i])
-        .     '&amp;what=' . urlencode($saved_attributes['saved_what'][$i])
-        .     '&amp;where=' . urlencode($saved_attributes['saved_where'][$i])
-        .   '>' . _("edit") . '</A>'
+        echo html_tag( 'td', imap_utf7_decode_local($saved_attributes['saved_folder'][$i]), 'left', '', 'width="35%"' )
+        . html_tag( 'td', $saved_attributes['saved_what'][$i], 'left' )
+        . html_tag( 'td', $saved_attributes['saved_where'][$i], 'center' )
+        . html_tag( 'td', '', 'right' )
+        .   '<a href=search.php'
+        .     '?mailbox=' . htmlspecialchars($saved_attributes['saved_folder'][$i])
+        .     '&amp;what=' . htmlspecialchars($saved_attributes['saved_what'][$i])
+        .     '&amp;where=' . htmlspecialchars($saved_attributes['saved_where'][$i])
+        .   '>' . _("edit") . '</a>'
         .   '&nbsp;|&nbsp;'
-        .   '<A HREF=search.php'
+        .   '<a href=search.php'
         .     '?mailbox=' . urlencode($saved_attributes['saved_folder'][$i])
         .     '&amp;what=' . urlencode($saved_attributes['saved_what'][$i])
         .     '&amp;where=' . urlencode($saved_attributes['saved_where'][$i])
         .     '&amp;submit=Search_no_update'
-        .   '>' . _("search") . '</A>'
+        .   '>' . _("search") . '</a>'
         .   '&nbsp;|&nbsp;'
-        .   "<A HREF=search.php?count=$i&amp;submit=delete>"
+        .   "<a href=search.php?count=$i&amp;submit=delete>"
         .     _("delete")
-        .   '</A>'
-        . '</TD></TR>';
+        .   '</a>'
+        . '</td></tr>';
     }
-    echo "</TABLE></TD></TR></TABLE>\n";
+    echo "</table></td></tr></table>\n";
 }
 
-/* Recent Search Table */
 if ($recent_count > 0) {
-    echo "<BR>\n"
-       . "<TABLE WIDTH=\"95%\" BGCOLOR=\"$color[9]\" ALIGN=\"CENTER\" CELLPADDING=1 CELLSPACING=1>\n"
-       . '<TR><TD ALIGN=CENTER><B>' . _("Recent Searches") . '</B></TD></TR><TR><TD>'
-       . '<TABLE WIDTH="100%" ALIGN="CENTER" CELLPADDING=0 CELLSPACING=0>';
+    echo "<br>\n"
+       . html_tag( 'table', '', 'center', $color[9], 'width="95%" cellpadding="1" cellspacing="1" border="0"' )
+       . html_tag( 'tr',
+             html_tag( 'td', '<b>' . _("Recent Searches") . '</b>', 'center' )
+         )
+       . html_tag( 'tr' )
+       . html_tag( 'td' )
+       . html_tag( 'table', '', 'center', '', 'width="100%" cellpadding="0" cellspacing="0" border="0"' );
     for ($i=1; $i <= $recent_count; ++$i) {
             if (isset($attributes['search_folder'][$i])) { 
             if ($attributes['search_folder'][$i] == "") {
@@ -301,71 +350,82 @@ if ($recent_count > 0) {
             }
             }
             if ($i % 2) {
-                echo "<TR BGCOLOR=\"$color[0]\">";
+                echo html_tag( 'tr', '', '', $color[0] );
             } else {
-                echo "<TR BGCOLOR=\"$color[4]\">";
+                echo html_tag( 'tr', '', '', $color[0] );
             }
             if (isset($attributes['search_what'][$i]) &&
                 !empty($attributes['search_what'][$i])) {
-            echo "<TD WIDTH=35%>".htmlentities($attributes['search_folder'][$i])."</TD>"
-               . "<TD ALIGN=LEFT>".htmlentities($attributes['search_what'][$i])."</TD>"
-               . "<TD ALIGN=CENTER>".htmlentities($attributes['search_where'][$i])."</TD>"
-               . '<TD ALIGN=RIGHT>'
-               .   "<A HREF=search.php?count=$i&amp;submit=save>"
+            echo html_tag( 'td', imap_utf7_decode_local($attributes['search_folder'][$i]), 'left', '', 'width="35%"' )
+               . html_tag( 'td', htmlspecialchars($attributes['search_what'][$i]), 'left' )
+               . html_tag( 'td', $attributes['search_where'][$i], 'center' )
+               . html_tag( 'td', '', 'right' )
+               .   "<a href=search.php?count=$i&amp;submit=save>"
                .     _("save")
-               .   '</A>'
+               .   '</a>'
                .   '&nbsp;|&nbsp;'
-               .   '<A HREF=search.php'
+               .   '<a href=search.php'
                .     '?mailbox=' . urlencode($attributes['search_folder'][$i])
                .     '&amp;what=' . urlencode($attributes['search_what'][$i])
                .     '&amp;where=' . urlencode($attributes['search_where'][$i])
                .     '&amp;submit=Search_no_update'
-               .   '>' . _("search") . '</A>'
+               .   '>' . _("search") . '</a>'
                .   '&nbsp;|&nbsp;'
-               .   "<A HREF=search.php?count=$i&amp;submit=forget>"
+               .   "<a href=search.php?count=$i&amp;submit=forget>"
                .     _("forget")
-               .   '</A>'
-               . '</TD></TR>';
+               .   '</a>'
+               . '</td></tr>';
         }
         }
-    echo '</TABLE></TD></TR></TABLE><BR>';
+    echo '</table></td></tr></table><br>';
 }
 
-/* Search Form */
-echo '<B>' . _("Current Search") . '</B>'
-   . '<FORM ACTION="search.php" NAME=s>'
-   . '   <TABLE WIDTH="95%" CELLPADDING=0 CELLSPACING=0>'
-   . '     <TR>'
-   . '       <TD><SELECT NAME="mailbox">';
-for ($i = 0; $i < count($boxes); $i++) {
-    if (!in_array('noselect', $boxes[$i]['flags'])) {
-        $box = $boxes[$i]['unformatted'];
-        $box2 = str_replace(' ', '&nbsp;',
-            imap_utf7_decode_local($boxes[$i]['unformatted-disp']));
-        if( $box2 == 'INBOX' ) {
-            $box2 = _("INBOX");
-        }
-        if ($mailbox == $box) {
-            echo "         <OPTION VALUE=\"$box\" SELECTED>$box2</OPTION>\n";
-        }
-        else {
-            echo "         <OPTION VALUE=\"$box\">$box2</OPTION>\n";
-        }
-    }
+
+if (isset($newsort)) {
+    $sort = $newsort;
+    sqsession_register($sort, 'sort');
 }
-        echo "<OPTION VALUE=\"All Folders\"";
-        if ($mailbox == "All Folders") {
-            echo "SELECTED";
-        }
-        echo ">All folders</OPTION>\n";
-echo '         </SELECT>'.
-     "       </TD>\n".
-     "        <TD ALIGN=\"CENTER\">\n";
+
+/*********************************************************************
+ * Check to see if we can use cache or not. Currently the only time  *
+ * when you will not use it is when a link on the left hand frame is *
+ * used. Also check to make sure we actually have the array in the   *
+ * registered session data.  :)                                      *
+ *********************************************************************/
+if (! isset($use_mailbox_cache)) {
+    $use_mailbox_cache = 0;
+}
+
+/* There is a problem with registered vars in 4.1 */
+/*
+if( substr( phpversion(), 0, 3 ) == '4.1'  ) {
+    $use_mailbox_cache = FALSE;
+}
+*/
+
+/* Search Form */
+echo html_tag( 'div', '<b>' . _("Current Search") . '</b>', 'left' ) . "\n"
+   . '<form action="search.php" name="s">'
+   . html_tag( 'table', '', '', '', 'width="95%" cellpadding="0" cellspacing="0" border="0"' )
+   . html_tag( 'tr' )
+   . html_tag( 'td', '', 'left' )
+   . '<select name="mailbox">'
+   . '<option value="All Folders"';
+   if ($mailbox == 'All Folders') {
+       echo ' selected';
+   }
+   echo '>[ ' . _("All Folders") . " ]</option>\n";
+
+   $show_selected = array(strtolower($mailbox));
+   echo sqimap_mailbox_option_list($imapConnection, $show_selected, 0, $boxes);
+
+   echo '         </select>'.
+        "       </td>\n";
 if ( !isset( $what ) ) {
     $what = '';
 }
 if ( !isset( $where ) ) {
-    $where = '';
+    $where = 'FROM';
 }
 
 
@@ -373,24 +433,22 @@ $what_disp = str_replace(',', ' ', $what);
 $what_disp = str_replace('\\\\', '\\', $what_disp);
 $what_disp = str_replace('\\"', '"', $what_disp);
 $what_disp = str_replace('"', '&quot;', $what_disp);
-echo "          <INPUT TYPE=\"TEXT\" SIZE=\"35\" NAME=\"what\" VALUE=\"$what_disp\">\n".
-     "        </TD>\n".
-     "<TD ALIGN=\"RIGHT\">\n".
-     "<SELECT NAME=\"where\">";
+echo html_tag( 'td', '<input type="text" size="35" name="what" value="' . $what_disp . '">' . "\n", 'center' )
+     . html_tag( 'td', '', 'right' )
+     . "<select name=\"where\">";
 s_opt( 'BODY', $where, _("Body") );
 s_opt( 'TEXT', $where, _("Everywhere") );
 s_opt( 'SUBJECT', $where, _("Subject") );
 s_opt( 'FROM', $where, _("From") );
 s_opt( 'CC', $where, _("Cc") );
 s_opt( 'TO', $where, _("To") );
-echo "         </SELECT>\n" .
-     "        </TD>\n".
-     "       <TD COLSPAN=\"3\" ALIGN=\"CENTER\">\n".
-     "         <INPUT TYPE=\"submit\" NAME=\"submit\" VALUE=\"" . _("Search") . "\">\n".
-     "       </TD>\n".
-     "     </TR>\n".
-     "</FORM>\n".
-     "   </TABLE>\n";
+echo "         </select>\n" .
+     "        </td>\n".
+     html_tag( 'td', '<input type="submit" name="submit" value="' . _("Search") . '">' . "\n", 'center', '', 'colspan="3"' ) .
+     "     </tr>\n".
+     "</form>\n".
+     "   </table>\n".
+     "</td></tr></table>\n";
 
 
 do_hook('search_after_form');
@@ -418,41 +476,49 @@ if ($search_all == 'all') {
         }
         if (($submit == _("Search") || $submit == 'Search_no_update') && !empty($what)) {
             sqimap_mailbox_select($imapConnection, $mailbox);
-            $count_all = sqimap_search($imapConnection, $where, $what, $mailbox, $color, 0, $search_all, $count_all);
-        array_push($perbox_count, $count_all);
+            $msgs = sqimap_search($imapConnection, $where, $what, $mailbox, $color, 0, $search_all, $count_all);
+	    $count_all = count($msgs);
+            printSearchMessages($msgs, $mailbox, $count_all, $imapConnection, 
+	                        $where, $what, false, false);
+            array_push($perbox_count, $count_all);
         }
     }
     for ($i=0;$i<count($perbox_count);$i++) {
-        if ($perbox_count[$i] != "") {
-            $count_all = "found";
+        if ($perbox_count[$i]) {
+            $count_all = true;
             break;
         }
     }
-    if ($count_all != "found") {
-        echo '<br><b>' .
-             _("No Messages found") .
-             '</b><br>';
+    if (!$count_all) {
+       echo '<br><center>' . _("No Messages Found") . '</center>';
     }
 }
 
 /*  search one folder option  */
 else {
     if (($submit == _("Search") || $submit == 'Search_no_update') && !empty($what)) {
-        echo '<BR><CENTER><B>' .
-             _("Search Results") .
-             "</B></CENTER>\n";
+        echo '<br>'
+        . html_tag( 'div', '<b>' . _("Search Results") . '</b>', 'center' ) . "\n";
         sqimap_mailbox_select($imapConnection, $mailbox);
-        sqimap_search($imapConnection, $where, $what, $mailbox, $color, 0, $search_all, $count_all);
+        $msgs = sqimap_search($imapConnection, $where, $what, $mailbox, $color, 0, $search_all, $count_all);
+	if (count($msgs)) {
+           printSearchMessages($msgs, $mailbox, count($msgs), $imapConnection,
+	                       $where, $what, false, false);
+	} else {
+           echo '<br><center>' . _("No Messages Found") . '</center>';
+	}
     }
 }
 
 /*  must have search terms to search  */
 if ($submit == _("Search") && empty($what)) {
-    echo "<BR><CENTER><B>Please enter something to search for</B></CENTER>\n";
+        echo '<br>'
+        . html_tag( 'div', '<b>Please enter something to search for</b>', 'center' ) . "\n";
 }
 
 $allow_thread_sort = $old_value;
 
+
 do_hook('search_bottom');
 sqimap_logout ($imapConnection);
 echo '</body></html>';
